==> aa_ledger-0.7.6.tar.gz: aa_ledger-0.7.6/ledger/views/character/planetary.py <==
"""
Planetary Audit
"""

# Standard Library
import logging
from http import HTTPStatus

# Django
from django.contrib.auth.decorators import login_required, permission_required
from django.db.models import Q
from django.http import JsonResponse
from django.shortcuts import redirect, render
from django.utils.translation import gettext_lazy as _
from django.views.decorators.http import require_POST

# AA Ledger
from ledger import forms
from ledger.api.helpers import get_alts_queryset, get_character
from ledger.models.planetary import CharacterPlanetDetails
from ledger.view_helpers.core import add_info_to_context

logger = logging.getLogger(__name__)


@login_required
@permission_required("ledger.basic_access")
def planetary_ledger_index(request):
    """Character Ledger Index View"""
    context = {}
    context = add_info_to_context(request, context)
    return redirect(
        "ledger:planetary_ledger", request.user.profile.main_character.character_id
    )


@login_required
@permission_required(["ledger.basic_access"])
def planetary_ledger(request, character_id=None):
    if character_id is None:
        character_id = request.user.profile.main_character.character_id

    context = {
        "title": "Planetary Ledger",
        "character_id": character_id,
        "forms": {
            "confirm": forms.ConfirmForm(),
        },
    }
    context = add_info_to_context(request, context)
    return render(
        request, "ledger/charledger/planetary/planetary_ledger.html", context=context
    )


@login_required
@permission_required("ledger.basic_access")
def planetary_overview(request):
    """
    Planetary Overview
    """

    context = {
        "title": "Planetary Overview",
    }
    context = add_info_to_context(request, context)

    return render(
        request,
        "ledger/charledger/planetary/admin/planetary_overview.html",
        context=context,
    )


@login_required
@permission_required("ledger.basic_access")
@require_POST
def switch_alarm(request):
    # Check Permission
    form = forms.ConfirmForm(request.POST)

    if form.is_valid():
        character_id = int(form.cleaned_data["character_id"])
        planet_id = int(form.cleaned_data["planet_id"])

        perm, main = get_character(request, character_id)

        if not perm:
            msg = _("Permission Denied")
            return JsonResponse(
                {"success": True, "message": msg},
                status=HTTPStatus.FORBIDDEN,
                safe=False,
            )

        if character_id == 0:
            characters = get_alts_queryset(main)
            characters = characters.values_list("character_id", flat=True)
        else:
            characters = [character_id]

        filters = Q(planet__character__character__character_id__in=characters)
        if planet_id != 0:
            filters &= Q(planet__planet__id=planet_id)
        try:
            planets = CharacterPlanetDetails.objects.filter(filters)

            if planets.exists():
                # Determine the majority state
                on_count = planets.filter(notification=True).count()
                off_count = planets.filter(notification=False).count()
                majority_state = on_count > off_count

                # Set all to the opposite of the majority state
                for p in planets:
                    p.notification = not majority_state
                    p.save()

                msg = _("All alarms successfully switched")
            else:
                raise CharacterPlanetDetails.DoesNotExist

        except CharacterPlanetDetails.DoesNotExist:
            msg = _("Planet/s not found")
            return JsonResponse(
                {"success": True, "message": msg},
                status=HTTPStatus.NOT_FOUND,
                safe=False,
            )

        return JsonResponse(
            {"success": True, "message": msg}, status=HTTPStatus.OK, safe=False
        )

    msg = "Invalid Form"
    return JsonResponse(
        {"success": False, "message": msg}, status=HTTPStatus.BAD_REQUEST, safe=False
    )

==> aa_ledger-0.8.2.tar.gz: aa_ledger-0.8.2/ledger/views/character/planetary.py <==
"""
Planetary Audit
"""

# Standard Library
import logging
from http import HTTPStatus

# Django
from django.contrib.auth.decorators import login_required, permission_required
from django.db.models import Q
from django.http import JsonResponse
from django.shortcuts import redirect, render
from django.utils.translation import gettext_lazy as _
from django.views.decorators.http import require_POST

# AA Ledger
from ledger import forms
from ledger.api.helpers import get_alts_queryset, get_character
from ledger.helpers.core import add_info_to_context
from ledger.models.planetary import CharacterPlanetDetails

logger = logging.getLogger(__name__)


@login_required
@permission_required("ledger.basic_access")
def planetary_ledger_index(request):
    """Character Ledger Index View"""
    context = {}
    context = add_info_to_context(request, context)
    return redirect(
        "ledger:planetary_ledger", request.user.profile.main_character.character_id
    )


@login_required
@permission_required(["ledger.basic_access"])
def planetary_ledger(request, character_id=None):
    if character_id is None:
        character_id = request.user.profile.main_character.character_id

    context = {
        "title": "Planetary Ledger",
        "character_id": character_id,
        "forms": {
            "confirm": forms.ConfirmForm(),
        },
    }
    context = add_info_to_context(request, context)
    return render(
        request, "ledger/charledger/planetary/planetary_ledger.html", context=context
    )


@login_required
@permission_required("ledger.basic_access")
def planetary_overview(request):
    """
    Planetary Overview
    """

    context = {
        "title": "Planetary Overview",
    }
    context = add_info_to_context(request, context)

    return render(
        request,
        "ledger/charledger/planetary/admin/planetary_overview.html",
        context=context,
    )


@login_required
@permission_required("ledger.basic_access")
@require_POST
def switch_alarm(request):
    # Check Permission
    form = forms.ConfirmForm(request.POST)

    if form.is_valid():
        is_all = False
        character_id = int(form.cleaned_data["character_id"])
        planet_id = int(form.cleaned_data["planet_id"])

        if character_id == 0:
            character_id = request.user.profile.main_character.character_id
            is_all = True

        perm, main = get_character(request, character_id)

        if not perm:
            msg = _("Permission Denied")
            return JsonResponse(
                {"success": True, "message": msg},
                status=HTTPStatus.FORBIDDEN,
                safe=False,
            )

        if is_all:
            characters = get_alts_queryset(main)
            characters = characters.values_list("character_id", flat=True)
        else:
            characters = [character_id]

        filters = Q(planet__character__character__character_id__in=characters)
        if planet_id != 0:
            filters &= Q(planet__planet__id=planet_id)
        try:
            planets = CharacterPlanetDetails.objects.filter(filters)

            if planets.exists():
                # Determine the majority state
                on_count = planets.filter(notification=True).count()
                off_count = planets.filter(notification=False).count()
                majority_state = on_count > off_count

                # Set all to the opposite of the majority state
                for p in planets:
                    p.notification = not majority_state
                    p.save()

                msg = _("All alarms successfully switched")
            else:
                raise CharacterPlanetDetails.DoesNotExist

        except CharacterPlanetDetails.DoesNotExist:
            msg = _("Planet/s not found")
            return JsonResponse(
                {"success": True, "message": msg},
                status=HTTPStatus.NOT_FOUND,
                safe=False,
            )

        return JsonResponse(
            {"success": True, "message": msg}, status=HTTPStatus.OK, safe=False
        )

    msg = "Invalid Form"
    return JsonResponse(
        {"success": False, "message": msg}, status=HTTPStatus.BAD_REQUEST, safe=False
    )
